==> platform_tab_bar_control-0.0.1.tar.gz: lib/platform_tab_bar_control.dart <==
library platform_tab_bar_control;
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class PlatformTabBarControl extends StatefulWidget {

  final TabController controller;
  final List<String> tabTitles;
  final PlatformTabSegmentedControlColors segmentedControlColors;

  PlatformTabBarControl({ @required this.controller, @required this.tabTitles, segmentedControlColors })
      : assert(controller != null && tabTitles != null),
        assert(controller.length == tabTitles.length),
        this.segmentedControlColors = segmentedControlColors ?? PlatformTabSegmentedControlColors();

  @override
  _PlatformTabBarControlState createState() => _PlatformTabBarControlState();
}

class _PlatformTabBarControlState extends State<PlatformTabBarControl> {

  int _segmentedControlValue = 0;

  @override
  void initState() {
    //The iOS Segment Control will start at the tab controller initial index
    _segmentedControlValue = widget.controller.index;

    if (Platform.isIOS) {
      //We only need this listener on iOS since the segmented control does not change automatically when the tab changes
      widget.controller.addListener(_tabViewChanged);
    }

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (Platform.isIOS) {
      return _buildCupertinoSegmentedControl();
    } else {
      return _buildMaterialTabBar();
    }
  }

  Widget _buildMaterialTabBar() {
    return TabBar(
      controller: widget.controller,
      tabs: widget.tabTitles
          .asMap()
          .map((index, value) {
        return MapEntry(
            index,
            Tab(
              text: value.toUpperCase(),
            )
        );
      })
          .values.toList(),
    );
  }

  Widget _buildCupertinoSegmentedControl() {
    return SizedBox(
      width: double.infinity,
      child: Padding(
        padding: EdgeInsets.symmetric(vertical: 8.0, horizontal: 8.0),
        child: CupertinoSegmentedControl(
          children: widget.tabTitles.asMap().map((index, value) {
            return MapEntry(
                index,
                Text(value)
            );
          }),
          onValueChanged: (int newValue) {
            widget.controller.animateTo(newValue);
          },
          groupValue: _segmentedControlValue,
          borderColor: widget.segmentedControlColors.borderColor,
          selectedColor: widget.segmentedControlColors.selectedColor,
          unselectedColor: widget.segmentedControlColors.unselectedColor,
          pressedColor: widget.segmentedControlColors.pressedColor,
        ),
      ),
    );
  }

  _tabViewChanged() {
    setState(() {
      _segmentedControlValue = widget.controller.index;
    });
  }
}

class PlatformTabSegmentedControlColors {
  final Color borderColor;
  final Color selectedColor;
  final Color unselectedColor;
  final Color pressedColor;

  PlatformTabSegmentedControlColors({
    this.borderColor,
    this.selectedColor,
    this.unselectedColor,
    this.pressedColor
  });
}

==> platform_tab_bar_control-0.0.2.tar.gz: lib/platform_tab_bar_control.dart <==
library platform_tab_bar_control;
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class PlatformTabBarControl extends StatefulWidget {

  final TabController controller;
  final List<String> tabTitles;
  final List<String> cupertinoTabTitles;
  final PlatformTabSegmentedControlColors segmentedControlColors;

  PlatformTabBarControl({ @required this.controller, @required this.tabTitles, this.cupertinoTabTitles, segmentedControlColors })
      : assert(controller != null && tabTitles != null),
        assert(controller.length == tabTitles.length),
        //If cupertinoTabTitle IS NOT null it MUST have the same length as the material tabTitles
        assert(cupertinoTabTitles == null || cupertinoTabTitles.length == tabTitles.length),
        this.segmentedControlColors = segmentedControlColors ?? PlatformTabSegmentedControlColors();

  @override
  _PlatformTabBarControlState createState() => _PlatformTabBarControlState();
}

class _PlatformTabBarControlState extends State<PlatformTabBarControl> {

  int _segmentedControlValue = 0;

  @override
  void initState() {
    //The iOS Segment Control will start at the tab controller initial index
    _segmentedControlValue = widget.controller.index;

    if (Platform.isIOS) {
      //We only need this listener on iOS since the segmented control does not change automatically when the tab changes
      widget.controller.addListener(_tabViewChanged);
    }

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (Platform.isIOS) {
      return _buildCupertinoSegmentedControl();
    } else {
      return _buildMaterialTabBar();
    }
  }

  Widget _buildMaterialTabBar() {
    return TabBar(
      controller: widget.controller,
      tabs: widget.tabTitles
          .asMap()
          .map((index, value) {
        return MapEntry(
            index,
            Tab(
              text: value.toUpperCase(),
            )
        );
      })
          .values.toList(),
    );
  }

  Widget _buildCupertinoSegmentedControl() {
    var tabTitlesToUse = widget.cupertinoTabTitles ?? widget.tabTitles;

    return SizedBox(
      width: double.infinity,
      child: Padding(
        padding: EdgeInsets.symmetric(vertical: 8.0, horizontal: 8.0),
        child: CupertinoSegmentedControl(
          children: tabTitlesToUse.asMap().map((index, value) {
            return MapEntry(
                index,
                Text(value)
            );
          }),
          onValueChanged: (int newValue) {
            widget.controller.animateTo(newValue);
          },
          groupValue: _segmentedControlValue,
          borderColor: widget.segmentedControlColors.borderColor,
          selectedColor: widget.segmentedControlColors.selectedColor,
          unselectedColor: widget.segmentedControlColors.unselectedColor,
          pressedColor: widget.segmentedControlColors.pressedColor,
        ),
      ),
    );
  }

  _tabViewChanged() {
    setState(() {
      _segmentedControlValue = widget.controller.index;
    });
  }
}

class PlatformTabSegmentedControlColors {
  final Color borderColor;
  final Color selectedColor;
  final Color unselectedColor;
  final Color pressedColor;

  PlatformTabSegmentedControlColors({
    this.borderColor,
    this.selectedColor,
    this.unselectedColor,
    this.pressedColor
  });
}
